@@ -224,9 +224,9 @@ class PortalBase:
         if not self._text:
             self.add_text()
         string = str(val)
-        if self._text[index]["maxlen"]:
+        if self._text[index]["maxlen"] and len(string) > self._text[index]["maxlen"]:
+            # too long! shorten it
             if len(string) >= 3:
-                # too long! shorten it
                 string = string[: self._text[index]["maxlen"] - 3] + "..."
             else:
                 string = string[: self._text[index]["maxlen"]]
@@ -392,7 +392,7 @@ class PortalBase:
         if self._text:
             value_index = 0  # In case values and text is not the same
             for i in range(len(self._text)):
-                if not self._text[i]["is_data"]:
+                if (not self._text[i]["is_data"]) or (value_index > (len(values) - 1)):
                     continue
                 string = None
                 if self._text[i]["transform"]:
